import os
import sys
from PIL import Image

# リサイズ後の画像を格納するサブフォルダの名前
output_subfolder = "resized"
target_width = 400  # 横幅を400pxにリサイズ

def resize_image(file_path, output_folder):
    # 画像を開く
    with Image.open(file_path) as img:
        # 横幅が指定幅より大きい場合のみ縮小
        if img.width > target_width:
            # 指定した幅にリサイズ
            width_percent = (target_width / float(img.width))
            new_height = int((float(img.height) * float(width_percent)))
            resized_img = img.resize((target_width, new_height), Image.ANTIALIAS)

            # リサイズされた画像を保存
            filename = os.path.basename(file_path)
            output_path = os.path.join(output_folder, filename)
            resized_img.save(output_path)
        else:
            # 指定した幅以下の場合、オリジナルの画像をコピー
            output_path = os.path.join(output_folder, os.path.basename(file_path))
            img.save(output_path)

def process_path(path):
    # フォルダか画像ファイルかをチェック
    if os.path.isdir(path):
        # フォルダの場合、フォルダ内のファイルを処理
        for root, _, files in os.walk(path):
            for file in files:
                file_path = os.path.join(root, file)
                process_path(file_path)
    elif os.path.isfile(path):
        # 画像ファイルの場合、画像をリサイズ
        valid_extensions = ('.jpg', '.jpeg', '.png', '.gif')  # 対応する画像フォーマットを追加
        if path.lower().endswith(valid_extensions):
            output_folder = os.path.join(os.path.dirname(path), output_subfolder)
            if not os.path.exists(output_folder):
                os.makedirs(output_folder)
            resize_image(path, output_folder)

if __name__ == "__main__":
    # ドラッグ&ドロップされたパスを処理
    for path in sys.argv[1:]:
        process_path(path)

    print("画像のリサイズが完了しました。")
